==> thx-job-import-export-0.0.7.tar.gz: thx-job-import-export-0.0.7/thx/job_import_export/jobs.py <==
# -*- coding: utf-8 -*-
from django.contrib.auth import get_user_model
from django.core.mail import EmailMessage
from django.urls import reverse
from django.utils.translation import gettext_lazy as _

from thx.cron.utils import JobHandler
from .utils import delete_private_file, generate_filename

User = get_user_model()


class ValidateAttributeMixin:
    @classmethod
    def get_job_name(cls):
        """Return job name"""
        if cls.job_name is None:
            raise AttributeError(_("'job_name' attribute not set for {}").format(cls.__name__))
        return cls.job_name

    @classmethod
    def get_job_command(cls):
        """Return job command"""
        if cls.job_command is None:
            raise AttributeError(_("'job_command' attribute not set for {}").format(cls.__name__))
        return cls.job_command

    def get_method(self):
        if not self.method:
            raise AttributeError(_("'method' attribute not set for {}").format(self.__class__.__name__))
        return self.method

    def get_model(self):
        """Return Model class"""
        if not self.model:
            raise AttributeError(_("'model' attribute not set for {}").format(self.__class__.__name__))
        return self.model

    def get_file_name(self):
        if not self.file_name:
            raise AttributeError(_("'file_name' attribute not set for {}").format(self.__class__.__name__))
        return self.file_name

    def get_download_url(self):
        if not self.download_url:
            raise AttributeError(_("'download_url' attribute not set for {}").format(self.__class__.__name__))
        return self.download_url

    def get_prefix_filepath(self):
        if not self.prefix_filepath:
            raise AttributeError(_("'get_prefix_filepath' attribute not set for {}").format(self.__class__.__name__))
        return self.prefix_filepath

    @classmethod
    def create(cls, creator, parameters):  # noqa
        job_name = cls.get_job_name()
        job_command = cls.get_job_command()
        return super().create(creator, job_name, job_command, parameters)


class ImportJob(ValidateAttributeMixin, JobHandler):
    method = None
    job_name = None
    job_command = None

    def run(self):
        user = User.objects.get(pk=self.parameters.get('user_id'))
        filename = self.parameters.get('filename')
        method = self.get_method()
        result_dict = method(user, filename)
        delete_private_file(user, filename)
        return result_dict

    def get_is_valid(self):
        results = self.elaboration_results
        success = results.get("success_count")
        warning = results.get("warning_count")
        error = results.get("error_count")
        return (
            (success and success > 0) or
            (warning and warning > 0) or
            (error and error > 0)
        )


class ExportJob(ValidateAttributeMixin, JobHandler):
    model = None
    method = None
    job_name = None
    job_command = None
    download_url = None
    prefix_filepath = None
    file_name = None

    _is_valid = True

    def get_file_name(self):
        file_name = self.parameters.get('file_name')
        if file_name:
            self.parameters.pop('file_name')
            self.file_name = file_name
            return self.file_name
        return super(ExportJob, self).get_file_name()

    def get_job_queryset(self):
        model = self.get_model()
        return model.objects.filter(**self.parameters)

    def run(self):
        model = self.get_model()
        user_id = self.parameters.pop('user_id')
        user = User.objects.get(pk=user_id)
        download_url = self.get_download_url()
        prefix_filepath = self.get_prefix_filepath()
        file_name = self.get_file_name()
        filename = generate_filename(user, file_name, prefix_filepath)
        queryset = self.get_job_queryset()
        method = self.get_method()

        created, filename_or_error = method(filename, queryset)
        delete_private_file(user, filename)
        if created:
            self._is_valid = True
            return {
                "filename": filename_or_error,
                "download_url": reverse(download_url, args=[file_name])
            }
        else:
            self._is_valid = False
            return {"error": str(filename_or_error)}

    def get_is_valid(self):
        return self._is_valid


class SendExportJob(ExportJob):
    @staticmethod
    def send_email(email, subject, filename):
        try:
            email_obj = EmailMessage(subject=subject, body='',  to=[email])
            email_obj.attach_file(filename)
            email_obj.send()
            return True, email
        except Exception as e:
            return False, e

    def run(self):
        model = self.get_model()
        user_id = self.parameters.pop('user_id')
        email = self.parameters.pop('email')
        subject = self.parameters.pop('subject')
        user = User.objects.get(pk=user_id)
        prefix_filepath = self.get_prefix_filepath()
        file_name = self.get_file_name()
        filename = generate_filename(user, file_name, prefix_filepath)
        queryset = model.objects.filter(**self.parameters)
        method = self.get_method()

        created, filename_or_error = method(filename, queryset)
        delete_private_file(user, filename)
        if created:
            sent, email_or_error = self.send_email(email, subject, filename)
            if sent:
                self._is_valid = True
                return {
                    "filename": filename_or_error,
                    "email": email_or_error
                }
            else:
                self._is_valid = False
                return {
                    "filename": filename_or_error,
                    "error": str(email_or_error)
                }
        else:
            self._is_valid = False
            return {
                "error": str(filename_or_error)
            }

==> thx-job-import-export-0.0.9.tar.gz: thx-job-import-export-0.0.9/thx/job_import_export/jobs.py <==
# -*- coding: utf-8 -*-
from django.contrib.auth import get_user_model
from django.core.mail import EmailMessage
from django.urls import reverse
from django.utils.translation import gettext_lazy as _

from thx.cron.utils import JSONJobHandler
from .utils import delete_private_file, generate_filename

User = get_user_model()


class ValidateAttributeMixin:
    @classmethod
    def get_job_name(cls):
        """Return job name"""
        if cls.job_name is None:
            raise AttributeError(_("'job_name' attribute not set for {}").format(cls.__name__))
        return cls.job_name

    @classmethod
    def get_job_command(cls):
        """Return job command"""
        if cls.job_command is None:
            raise AttributeError(_("'job_command' attribute not set for {}").format(cls.__name__))
        return cls.job_command

    def get_method(self):
        if not self.method:
            raise AttributeError(_("'method' attribute not set for {}").format(self.__class__.__name__))
        return self.method

    def get_model(self):
        """Return Model class"""
        if not self.model:
            raise AttributeError(_("'model' attribute not set for {}").format(self.__class__.__name__))
        return self.model

    def get_file_name(self):
        if not self.file_name:
            raise AttributeError(_("'file_name' attribute not set for {}").format(self.__class__.__name__))
        return self.file_name

    def get_download_url(self):
        if not self.download_url:
            raise AttributeError(_("'download_url' attribute not set for {}").format(self.__class__.__name__))
        return self.download_url

    def get_prefix_filepath(self):
        if not self.prefix_filepath:
            raise AttributeError(_("'get_prefix_filepath' attribute not set for {}").format(self.__class__.__name__))
        return self.prefix_filepath

    @classmethod
    def create(cls, creator, parameters):  # noqa
        job_name = cls.get_job_name()
        job_command = cls.get_job_command()
        return super().create(creator, job_name, job_command, parameters)


class ImportJob(ValidateAttributeMixin, JSONJobHandler):
    method = None
    job_name = None
    job_command = None

    def run(self):
        user = User.objects.get(pk=self.parameters.get('user_id'))
        filename = self.parameters.get('filename')
        method = self.get_method()
        result_dict = method(user, filename)
        delete_private_file(user, filename)
        return result_dict

    def get_is_valid(self):
        results = self.elaboration_results
        success = results.get("success_count")
        warning = results.get("warning_count")
        error = results.get("error_count")
        return (
            (success and success > 0) or
            (warning and warning > 0) or
            (error and error > 0)
        )


class ExportJob(ValidateAttributeMixin, JSONJobHandler):
    model = None
    method = None
    job_name = None
    job_command = None
    download_url = None
    prefix_filepath = None
    file_name = None

    _is_valid = True

    def get_file_name(self):
        file_name = self.parameters.get('file_name')
        if file_name:
            self.parameters.pop('file_name')
            self.file_name = file_name
            return self.file_name
        return super(ExportJob, self).get_file_name()

    def get_job_queryset(self):
        model = self.get_model()
        return model.objects.filter(**self.parameters)

    def run(self):
        model = self.get_model()
        user_id = self.parameters.pop('user_id')
        user = User.objects.get(pk=user_id)
        download_url = self.get_download_url()
        prefix_filepath = self.get_prefix_filepath()
        file_name = self.get_file_name()
        filename = generate_filename(user, file_name, prefix_filepath)
        queryset = self.get_job_queryset()
        method = self.get_method()

        created, filename_or_error = method(filename, queryset)
        delete_private_file(user, filename)
        if created:
            self._is_valid = True
            return {
                "filename": filename_or_error,
                "download_url": reverse(download_url, args=[file_name])
            }
        else:
            self._is_valid = False
            return {"error": str(filename_or_error)}

    def get_is_valid(self):
        return self._is_valid


class SendExportJob(ExportJob):
    @staticmethod
    def send_email(email, subject, filename):
        try:
            email_obj = EmailMessage(subject=subject, body='',  to=[email])
            email_obj.attach_file(filename)
            email_obj.send()
            return True, email
        except Exception as e:
            return False, e

    def run(self):
        model = self.get_model()
        user_id = self.parameters.pop('user_id')
        email = self.parameters.pop('email')
        subject = self.parameters.pop('subject')
        user = User.objects.get(pk=user_id)
        prefix_filepath = self.get_prefix_filepath()
        file_name = self.get_file_name()
        filename = generate_filename(user, file_name, prefix_filepath)
        queryset = model.objects.filter(**self.parameters)
        method = self.get_method()

        created, filename_or_error = method(filename, queryset)
        delete_private_file(user, filename)
        if created:
            sent, email_or_error = self.send_email(email, subject, filename)
            if sent:
                self._is_valid = True
                return {
                    "filename": filename_or_error,
                    "email": email_or_error
                }
            else:
                self._is_valid = False
                return {
                    "filename": filename_or_error,
                    "error": str(email_or_error)
                }
        else:
            self._is_valid = False
            return {
                "error": str(filename_or_error)
            }
